==> eudplib-0.71.1-cp310-cp310-win_amd64.whl: eudplib/ctrlstru/cshelper.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014 trgk

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
"""


from eudplib.localize import _


class CtrlStruOpener:
    def __init__(self, f):
        self._f = f
        self._called = False

    def __del__(self):
        if not self._called:
            raise RuntimeError(
                _("Control structures must be double-parenthesised.") + "\n ex) EUDInfLoop()()"
            )

    def __bool__(self):
        raise RuntimeError(
            _("Control structures must be double-parenthesised.") + "\n ex) EUDInfLoop()()"
        )

    def __call__(self, *args, **kwargs):
        self._called = True
        return self._f(*args, **kwargs)

==> eudplib-0.73.19-cp310-cp310-win_amd64.whl: eudplib/ctrlstru/cshelper.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014 trgk

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
"""


from collections.abc import Callable
from typing import NoReturn
from eudplib.localize import _


class CtrlStruOpener:
    def __init__(self, f: Callable) -> None:
        self._f: Callable = f
        self._called = False

    def __del__(self) -> None:
        if not self._called:
            raise RuntimeError(
                _("Control structures must be double-parenthesised.") + "\n ex) EUDInfLoop()()"
            )

    def __bool__(self) -> NoReturn:
        raise RuntimeError(
            _("Control structures must be double-parenthesised.") + "\n ex) EUDInfLoop()()"
        )

    def __call__(self, *args, **kwargs):
        self._called = True
        return self._f(*args, **kwargs)
